# from AutoEncoder import cut_list, show_face_data
# from evolutionary import cross_over, mutation, get_children_from_parent
# from filter_data import filter, split_encoded_images
# from interface import initialize, onClick, fevent, hevent, bevent, nbevent, oevent, yevent, sevent, nsevent
# from interface import sex_characteristics, choice_database, reselect, inital_population, chooseimage, end_or_continue, found_agressor
